+++
title = "Replace keys using multiple properties"
keywords = ["front-matter", "keys", "replace", "tags", "categories"]
cats = ["test-cat-x"]
draft = false
+++

This post will have the `tags` key in front-matter replaced with
`keywords` and `categories` replaced with `cats`.
